@@ -47,7 +47,7 @@ def _parseVariables( variable):
 
        return tokens
 
-def _insertVariables( variableDict, valuesDict, str):
+def _insertVariables(variableDict, valuesDict, str):
         newURL = str
 
         # when we change the length of array, we need to fix indexes
@@ -57,12 +57,16 @@ def _insertVariables( variableDict, valuesDict, str):
         # len(varValue) - len (varName)
         offset = 0
         for i in variableDict:
+            value = ''
+            if i in valuesDict:
+                value = valuesDict[i]
+
             rightIndex = variableDict[i][0] + offset
             leftIndex = variableDict[i][1] + 2 + offset
-            offset += ( len(valuesDict[i]) -  len(i))
+            offset += ( len(value) -  len(i))
 
             newURL = str[0:rightIndex]
-            newURL += valuesDict[i]
+            newURL += value
             if len(str) > leftIndex:
                 newURL += str[leftIndex:]
             str = newURL
@@ -98,11 +102,12 @@ def _configureHTTPVariables( data):
 
     # --
     # Methods that make HTTP Request
-def _makeRequest(data,response=None):
+def _makeRequest(data):
 
         currentAttempt = 0
         result = None
         workingOnReq = True
+        err = None
         while currentAttempt - 1 < data["retry"] and workingOnReq:
             
             try:
@@ -116,14 +121,17 @@ def _makeRequest(data,response=None):
                         result = req.text
 
                     workingOnReq = False
-            except Exception as e:
+            except BaseException as e:
                 err = e
             currentAttempt += 1
 
         if result is None:
-            raise Exception("API Call Failed ")
+
+            if err is None:
+                raise Exception('Failed to connect to ' + data['url'])
+            else:
+                raise err
         else:
-            response = result
             return result
 
 def _requestsWrapper(url,method,body=None,headers=None, timeout=None):
